Module model

Module model 

Structs

BlockHeight
BlockId
A cryptographically secure hash, identifying a block.
CheckedMessage
Coin
Represents the user’s coin for some asset with asset_id. The Coin is either CoinStatus::Spent or CoinStatus::Unspent. If the coin is unspent, it can be used as an input to the transaction and can be spent up to the amount. After usage as an input of a transaction, the Coin becomes CoinStatus::Spent.
ConsensusVote
A vote from a validator.
DaBlockHeight
Empty
Empty generated fields.
FuelApplicationHeader
The fuel block application header. Contains everything except consensus related data.
FuelBlock
Fuel block with all transaction data included
FuelBlockDb
The compact representation of a block used in the database
FuelBlockHeader
A fuel block header that has all the fields generated because it has been executed.
FuelBlockPoAConsensus
The consensus related data that doesn’t live on the header.
FuelConsensusHeader
The fuel block consensus header. This contains fields related to consensus plus the hash of the FuelApplicationHeader.
Genesis
The first block of the blockchain is a genesis block. It determines the initial state of the network - contracts states, contracts balances, unspent coins, and messages. It also contains the hash on the initial config of the network that defines the consensus rules for following blocks.
Message
Message send from Da layer to fuel by bridge
MessageProof
PartialFuelBlock
Fuel block with all transaction data included but without any data generated. This type can be created with unexecuted transactions to produce a FuelBlock or it can be created with pre-executed transactions in order to validate they were constructed correctly.
PartialFuelBlockHeader
A partially complete fuel block header that doesn’t not have any generated fields because it has not been executed yet.
SealedFuelBlock
A fuel block with the related consensus data.
SealedFuelBlockHeader
A fuel block with the related consensus data.
SecretKeyWrapper
Wrapper around [fuel_crypto::SecretKey] to implement secrecy marker traits
TxInfo

Enums

CoinStatus
ConsensusType
FuelBlockConsensus
The consensus related data that doesn’t live on the header.

Type Aliases

ArcPoolTx
ConsensusId
Consensus public key used for Fuel network consensus protocol to check signatures. ConsensusId is assigned by validator.
ValidatorId
Validator address used for registration of validator on DA layer