pub enum FuelBlockConsensus {
PoA(FuelBlockPoAConsensus),
Genesis(Genesis),
}Expand description
The consensus related data that doesn’t live on the header.
Variants
PoA(FuelBlockPoAConsensus)
Genesis(Genesis)
The genesis block defines the consensus rules for future blocks.
Implementations
Sourceimpl FuelBlockConsensus
impl FuelBlockConsensus
Sourcepub fn block_producer(&self, block_id: &BlockId) -> Result<Address>
pub fn block_producer(&self, block_id: &BlockId) -> Result<Address>
Retrieve the block producer address from the consensus data