pub struct Coin {
pub owner: Address,
pub amount: Word,
pub asset_id: AssetId,
pub maturity: BlockHeight,
pub status: CoinStatus,
pub block_created: BlockHeight,
}Expand description
Represents the user’s coin for some asset with asset_id.
The Coin is either CoinStatus::Spent or CoinStatus::Unspent. If the coin is unspent,
it can be used as an input to the transaction and can be spent up to the amount.
After usage as an input of a transaction, the Coin becomes CoinStatus::Spent.
Fields
owner: Addressamount: Wordasset_id: AssetIdmaturity: BlockHeightstatus: CoinStatusblock_created: BlockHeightTrait Implementations