Struct fuel_core_interfaces::model::FuelApplicationHeader
source · pub struct FuelApplicationHeader<Generated> {
pub da_height: DaBlockHeight,
pub generated: Generated,
}Expand description
The fuel block application header. Contains everything except consensus related data.
Fields
da_height: DaBlockHeightThe layer 1 height of messages and events to include since the last layer 1 block number. This is not meant to represent the layer 1 block this was committed to. Validators will need to have some rules in place to ensure the block number was chosen in a reasonable way. For example, they should verify that the block number satisfies the finality requirements of the layer 1 chain. They should also verify that the block number isn’t too stale and is increasing. Some similar concerns are noted in this issue: https://github.com/FuelLabs/fuel-specs/issues/220
generated: GeneratedGenerated application fields.