Struct fuel_core_interfaces::model::FuelBlockDb
source · pub struct FuelBlockDb {
pub header: FuelBlockHeader,
pub transactions: Vec<Bytes32>,
}Expand description
The compact representation of a block used in the database
Fields
header: FuelBlockHeadertransactions: Vec<Bytes32>Implementations
sourceimpl FuelBlockDb
impl FuelBlockDb
sourcepub fn consensus_type(&self) -> ConsensusType
pub fn consensus_type(&self) -> ConsensusType
The type of consensus this header is using.
sourcepub fn fix_me_default_block() -> Self
pub fn fix_me_default_block() -> Self
Hack until we completely remove the need for meaningless default headers.