pub struct FuelBlockHeader {
    pub height: BlockHeight,
    pub da_height: DaBlockHeight,
    pub parent_hash: Bytes32,
    pub prev_root: Bytes32,
    pub transactions_root: Bytes32,
    pub time: DateTime<Utc>,
    pub producer: Address,
    pub metadata: Option<HeaderMetadata>,
}

Fields

height: BlockHeight

Fuel block height.

da_height: DaBlockHeight

The layer 1 height of messages and events to include since the last layer 1 block number. This is not meant to represent the layer 1 block this was committed to. Validators will need to have some rules in place to ensure the block number was chosen in a reasonable way. For example, they should verify that the block number satisfies the finality requirements of the layer 1 chain. They should also verify that the block number isn’t too stale and is increasing. Some similar concerns are noted in this issue: https://github.com/FuelLabs/fuel-specs/issues/220

parent_hash: Bytes32

Block header hash of the previous block.

prev_root: Bytes32

Merkle root of all previous block header hashes.

transactions_root: Bytes32

Merkle root of transactions.

time: DateTime<Utc>

The block producer time

producer: Address

The block producer public key

metadata: Option<HeaderMetadata>

Header Metadata

Implementations