pub struct Message {
pub sender: Address,
pub recipient: Address,
pub nonce: Word,
pub amount: Word,
pub data: Vec<u8>,
pub da_height: DaBlockHeight,
pub fuel_block_spend: Option<BlockHeight>,
}Expand description
Message send from Da layer to fuel by bridge
Fields
sender: Addressrecipient: Addressnonce: Wordamount: Worddata: Vec<u8>da_height: DaBlockHeightThe block height from the parent da layer that originated this message
fuel_block_spend: Option<BlockHeight>Implementations