pub enum DaSyncState {
    RelayerSyncing,
    OverlapingSync,
    Synced,
}

Variants

RelayerSyncing

relayer is syncing old state

OverlapingSync

fetch last N blocks to get their logs. Parse them and save them inside pending state in parallel start receiving logs from stream and overlap them. when first fetch is finished discard all logs from log stream and start receiving new onews.

Synced

We have all past logs ready and can just listen to new ones commint from eth