Enum fuel_core_interfaces::relayer::RelayerEvent
source · [−]pub enum RelayerEvent {
GetValidatorSet {
da_height: DaBlockHeight,
response_channel: Sender<Result<ValidatorSet, RelayerError>>,
},
GetStatus {
response: Sender<RelayerStatus>,
},
Stop,
}Variants
GetValidatorSet
Fields
da_height: DaBlockHeightrepresent validator set for current block and it is on relayer to calculate it with slider in mind.
response_channel: Sender<Result<ValidatorSet, RelayerError>>GetStatus
Fields
response: Sender<RelayerStatus>Stop