Struct fuel_core_interfaces::relayer::StakingDiff
source · [−]pub struct StakingDiff {
pub validators: HashMap<Address, Option<Address>>,
pub delegations: HashMap<Address, Option<HashMap<Address, ValidatorStake>>>,
}Fields
validators: HashMap<Address, Option<Address>>Validator registration, it can be new consensus address if registered or None if unregistration happened.
delegations: HashMap<Address, Option<HashMap<Address, ValidatorStake>>>Register changes for all delegations inside one da block.
Implementations