Module db Copy item path Source Coins The storage table of coins. Each Coin is represented by unique UtxoId. ContractsAssets The storage table for contract’s assets balances. ContractsInfo The storage table for contract’s additional information as salt, root hash, etc. ContractsLatestUtxo The latest UTXO id of the contract. The contract’s UTXO represents the unique id of the state.
After each transaction, old UTXO is consumed, and new UTXO is produced. UTXO is used as an
input to the next transaction related to the ContractId smart contract. ContractsRawCode The storage table for contract’s raw byte code. ContractsState The storage table for contract’s hashed key-value state. FuelBlocks The table of blocks generated by Fuels validators.
Right now, we have only that type of block, but we will support others in the future. Messages The storage table of bridged Ethereum Message s. Receipts Receipts of different hidden internal operations. SealedBlockConsensus The table of consensus metadata associated with sealed (finalized) blocks Transactions The storage table of confirmed transactions. Error KvStoreError DatabaseTransaction The database transaction for the Database type. Transactional