Represents the user’s coin for some asset with asset_id.
The Coin is either CoinStatus::Spent or CoinStatus::Unspent. If the coin is unspent,
it can be used as an input to the transaction and can be spent up to the amount.
After usage as an input of a transaction, the Coin becomes CoinStatus::Spent.
The first block of the blockchain is a genesis block. It determines the initial state of the
network - contracts states, contracts balances, unspent coins, and messages. It also contains
the hash on the initial config of the network that defines the consensus rules for following
blocks.
Fuel block with all transaction data included
but without any data generated.
This type can be created with unexecuted
transactions to produce a FuelBlock or
it can be created with pre-executed transactions in
order to validate they were constructed correctly.