Struct fuel_core_interfaces::model::FuelBlockConsensus
source · [−]pub struct FuelBlockConsensus {
pub required_stake: u64,
pub validators: HashMap<Address, (ValidatorStake, Address)>,
}Expand description
This structure is ceated as placeholder for future usage. It represent commitment for next child block
Fields
required_stake: u64required stake for next block
validators: HashMap<Address, (ValidatorStake, Address)>Map of Validator consensus key and pair of stake and signature