Struct fuel_core_interfaces::model::FuelBlockHeader
source · [−]pub struct FuelBlockHeader {
pub height: BlockHeight,
pub number: BlockHeight,
pub parent_hash: Bytes32,
pub prev_root: Bytes32,
pub transactions_root: Bytes32,
pub time: DateTime<Utc>,
pub producer: Address,
pub metadata: Option<HeaderMetadata>,
}Fields
height: BlockHeightFuel block height.
number: BlockHeightThe layer 1 height of deposits and events to include since the last layer 1 block number. This is not meant to represent the layer 1 block this was committed to. Validators will need to have some rules in place to ensure the block number was chosen in a reasonable way. For example, they should verify that the block number satisfies the finality requirements of the layer 1 chain. They should also verify that the block number isn’t too stale and is increasing. Some similar concerns are noted in this issue: https://github.com/FuelLabs/fuel-specs/issues/220
parent_hash: Bytes32Block header hash of the previous block.
prev_root: Bytes32Merkle root of all previous block header hashes.
transactions_root: Bytes32Merkle root of transactions.
time: DateTime<Utc>The block producer time
producer: AddressThe block producer public key
metadata: Option<HeaderMetadata>Header Metadata
Implementations
sourceimpl FuelBlockHeader
impl FuelBlockHeader
pub fn recalculate_metadata(&mut self)
pub fn id(&self) -> Bytes32